summaryrefslogtreecommitdiff
path: root/src/components/connection_handler/src/connection_handler_impl.cc
diff options
context:
space:
mode:
authorfronneburg <fronneburg@xevo.com>2018-06-27 14:45:18 -0700
committerfronneburg <fronneburg@xevo.com>2018-06-27 15:37:23 -0700
commit8fda3ea7b563cc5d343dc6e9a4dbd094c1085659 (patch)
treed65c7d721f46ddb8e64cc98a703fceb5c5dd4a39 /src/components/connection_handler/src/connection_handler_impl.cc
parentb4c6b5e040783ccd8cb74d411024d3b8a19c9c84 (diff)
downloadsdl_core-8fda3ea7b563cc5d343dc6e9a4dbd094c1085659.tar.gz
further review comments
Diffstat (limited to 'src/components/connection_handler/src/connection_handler_impl.cc')
-rw-r--r--src/components/connection_handler/src/connection_handler_impl.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/components/connection_handler/src/connection_handler_impl.cc b/src/components/connection_handler/src/connection_handler_impl.cc
index a2883c9137..8af0d85edf 100644
--- a/src/components/connection_handler/src/connection_handler_impl.cc
+++ b/src/components/connection_handler/src/connection_handler_impl.cc
@@ -1026,11 +1026,11 @@ SessionTransports ConnectionHandlerImpl::SetSecondaryTransportID(
st = it->second;
// The only time we overwrite an existing entry in the map is if the new
// secondary transport ID is DISABLED_SECONDARY, which effectively DISABLES
// the secondary transport feature for the session, or if the new secondary
// transport ID is 0, which means a secondary transport has shut down
if (st.secondary_transport != 0 &&
- secondary_transport_id != DISABLED_SECONDARY &&
+ secondary_transport_id != kDisabledSecondary &&
secondary_transport_id != 0) {
LOG4CXX_WARN(logger_,
"SetSecondaryTransportID: session ID "
@@ -1026,11 +1026,11 @@ SessionTransports ConnectionHandlerImpl::SetSecondaryTransportID(
st = it->second;
// The only time we overwrite an existing entry in the map is if the new
- // secondary transport ID is DISABLED_SECONDARY, which effectively DISABLES
+ // secondary transport ID is kDisabledSecondary, which effectively DISABLES
// the secondary transport feature for the session, or if the new secondary
// transport ID is 0, which means a secondary transport has shut down